package pt.digitalis.sandbox.ioc;

import java.util.List;

import pt.digitalis.log.ILogWrapper;
import pt.digitalis.utils.ioc.IIoCRegistry;
import pt.digitalis.utils.ioc.guice.IoCRegistryGuiceImpl;

/**
 * Client class for the File Exporter services.
 * 
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a>
 * @author Rodrigo Gonalves <a href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a><br/>
 * @created Oct 22, 2007
 */
public class SampleApp {

    /**
     * The main.
     * 
     * @param args
     *            the main arguments
     * @throws Exception
     *             if anything goes wrong
     */
    public static void main(String[] args) throws Exception {

        IIoCRegistry registry = IoCRegistryGuiceImpl.getRegistry();

        ILogWrapper logger = registry.getImplementation(ILogWrapper.class);
        List<IFileExporter> exporters = registry.getImplementations(IFileExporter.class);

        logger.setInfoLogLevel();
        logger.info("Starting export of file to all " + exporters.size() + " supported formats...");

        for (IFileExporter exporter : exporters) {
            exporter.exportFile("mockupFileName");
        }

        logger.info("Export complete.");
    }
}
